==> ns-sso-client-2.0.0-20250828.060253-41-sources.jar: com/geoway/sso/client/aspect/RequireAuthAspect.java <==
package com.geoway.sso.client.aspect;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;

import com.geoway.sso.client.annotation.RequireAuth;
import com.geoway.sso.client.client.impl.TenantClientImpl;
import com.geoway.sso.client.enums.RoleLevelEnum;
import com.geoway.sso.client.constant.SsoConstant;
import com.geoway.sso.client.rpc.SsoUser;
import com.geoway.sso.client.util.CommonLoginUserUtil;
import com.geoway.sso.client.util.HttpServletUtil;
import lombok.extern.slf4j.Slf4j;

import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.Signature;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletResponse;
import java.lang.reflect.Method;



/**
 * 接口日志保存切面方法
 */
@Slf4j
@Aspect
@Service
@ConditionalOnExpression("#{!T(com.geoway.sso.client.constant.SystemConstant).IS_SERVER}")
@SuppressWarnings("all")
public class RequireAuthAspect {

    @Autowired
    TenantClientImpl tenantClientImpl;
    /**
     *  配置织入点
     */
    //@Pointcut("@annotation(com.geoway.sso.client.annotation.RequireAuth)")
    @Pointcut("@within(com.geoway.sso.client.annotation.RequireAuth)")
    public void authClassPointCut() {
    }

    @Before("authClassPointCut()")
    public void beforeClassExec(JoinPoint joinPoint) {
        excute(joinPoint);
    }
    /**
     *  配置织入点
     */
    //@Pointcut("@annotation(com.geoway.sso.client.annotation.RequireAuth)")
    @Pointcut("@annotation(com.geoway.sso.client.annotation.RequireAuth)")
    public void authMethodPointCut() {
    }

    @Before("authMethodPointCut()")
    public void beforeMethodExec(JoinPoint joinPoint) {
        excute(joinPoint);
    }
    private void excute(JoinPoint joinPoint){
        RequireAuth requireAuth = getAnnotationAuth(joinPoint);
        if(requireAuth==null||requireAuth.roleLevel()== RoleLevelEnum.None){
            return;
        }
        SsoUser sysUser = CommonLoginUserUtil.getUser();// oauth2Service.queryCurrentSsoUser(request);
        if(sysUser==null){
            markLoginResponse("用户无权限访问");
            return;
        }
        switch (requireAuth.roleLevel()){
            case superAdmin:
                if(sysUser.getUserCatalog().equals(RoleLevelEnum.superAdmin.getValue())){
                    return;
                }
                throw new RuntimeException("用户无权限访问,需系统管理员权限");
            case tenantAdmin:
                if(sysUser.getUserCatalog()> RoleLevelEnum.tenantAdmin.getValue()){
                    throw new RuntimeException("用户无权限访问,需管理员权限");
                }
                if(!tenantClientImpl.isTenantAdmin()){
                    throw new RuntimeException("用户无权限访问,需管理员权限");
                }
            case commonUser:
                if(sysUser.getUserCatalog()> RoleLevelEnum.commonUser.getValue()){
                    throw new RuntimeException("游客无访问权限");
                }
        }
    }


    /**
     * 是否存在注解，如果存在就获取
     * @param joinPoint
     * @return
     */
    private RequireAuth getAnnotationAuth(JoinPoint joinPoint) {
        Signature signature = joinPoint.getSignature();
        MethodSignature methodSignature = (MethodSignature) signature;
        Method method = methodSignature.getMethod();
        RequireAuth requireAuth=null;
        if (method != null) {
            requireAuth= method.getAnnotation(RequireAuth.class);
        }
        if(requireAuth!=null){
            return requireAuth;
        }
        Class classT=methodSignature.getDeclaringType();
        if (classT != null) {
            requireAuth= (RequireAuth)classT.getAnnotation(RequireAuth.class);
        }
        return requireAuth;
    }

    //前后端分离登录拦截返回
    private void markLoginResponse(String msg) {
        try {
            HttpServletResponse response = HttpServletUtil.getResponse();
            response.setStatus(HttpStatus.OK.value());
            response.setContentType(MediaType.APPLICATION_JSON_VALUE);
            response.setCharacterEncoding("UTF-8");
            response.setHeader("Cache-Control", "no-cache, must-revalidate");
            JSONObject baseResopnse = new JSONObject();
            baseResopnse.put("code", SsoConstant.NO_LOGIN);
            baseResopnse.put("status", SsoConstant.RESPONSE_STATUS_LOGINOUT);
            baseResopnse.put("message", "无效token或token已过期");
            if (StrUtil.isNotEmpty(msg)) {
                baseResopnse.put("message", msg);
            }
            String jsonResult = JSON.toJSONString(baseResopnse, SerializerFeature.WriteNullStringAsEmpty);
            response.getOutputStream().write(jsonResult.getBytes());
        }catch (Exception exception){
            throw new RuntimeException(exception);
        }
    }
}

==> ns-sso-client-2.0.0-20251120.075102-68-sources.jar: com/geoway/sso/client/aspect/RequireAuthAspect.java <==
package com.geoway.sso.client.aspect;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;

import com.geoway.sso.client.annotation.RequireAuth;
import com.geoway.sso.client.client.TenantClient;
import com.geoway.sso.client.client.impl.TenantClientImpl;
import com.geoway.sso.client.enums.RoleLevelEnum;
import com.geoway.sso.client.constant.SsoConstant;
import com.geoway.sso.client.rpc.SsoUser;
import com.geoway.sso.client.util.CommonLoginUserUtil;
import com.geoway.sso.client.util.HttpServletUtil;
import lombok.extern.slf4j.Slf4j;

import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.Signature;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletResponse;
import java.lang.reflect.Method;



/**
 * 接口日志保存切面方法
 */
@Slf4j
@Aspect
@Service
@ConditionalOnExpression("#{!T(com.geoway.sso.client.constant.SystemConstant).IS_SERVER}")
@SuppressWarnings("all")
public class RequireAuthAspect {

    @Autowired
    TenantClient tenantClientImpl;
    /**
     *  配置织入点
     */
    //@Pointcut("@annotation(com.geoway.sso.client.annotation.RequireAuth)")
    @Pointcut("@within(com.geoway.sso.client.annotation.RequireAuth)")
    public void authClassPointCut() {
    }

    @Before("authClassPointCut()")
    public void beforeClassExec(JoinPoint joinPoint) {
        excute(joinPoint);
    }
    /**
     *  配置织入点
     */
    //@Pointcut("@annotation(com.geoway.sso.client.annotation.RequireAuth)")
    @Pointcut("@annotation(com.geoway.sso.client.annotation.RequireAuth)")
    public void authMethodPointCut() {
    }

    @Before("authMethodPointCut()")
    public void beforeMethodExec(JoinPoint joinPoint) {
        excute(joinPoint);
    }
    private void excute(JoinPoint joinPoint){
        RequireAuth requireAuth = getAnnotationAuth(joinPoint);
        if(requireAuth==null||requireAuth.roleLevel()== RoleLevelEnum.None){
            return;
        }
        SsoUser sysUser = CommonLoginUserUtil.getUser();// oauth2Service.queryCurrentSsoUser(request);
        if(sysUser==null){
            markLoginResponse("用户无权限访问");
            return;
        }
        switch (requireAuth.roleLevel()){
            case superAdmin:
                if(sysUser.getUserCatalog().equals(RoleLevelEnum.superAdmin.getValue())){
                    return;
                }
                throw new RuntimeException("用户无权限访问,需系统管理员权限");
            case tenantAdmin:
                if(RoleLevelEnum.getEnumByValue(sysUser.getUserCatalog()).getLevel()> RoleLevelEnum.tenantAdmin.getLevel()){
                    throw new RuntimeException("用户无权限访问,需租户管理员权限");
                }
                if(!tenantClientImpl.isTenantAdmin()){
                    throw new RuntimeException("用户无权限访问,需租户管理员权限");
                }
                break;
            case bizAdmin:
                if(RoleLevelEnum.getEnumByValue(sysUser.getUserCatalog()).getLevel()> RoleLevelEnum.bizAdmin.getLevel()){
                    throw new RuntimeException("用户无权限访问,需业务管理员权限");
                }
                if(sysUser.getUserCatalog().equals(RoleLevelEnum.tenantAdmin)&&!tenantClientImpl.isTenantAdmin()){
                    throw new RuntimeException("用户无权限访问,需业务管理员权限");
                }
                break;
            case commonUser:
                if(RoleLevelEnum.getEnumByValue(sysUser.getUserCatalog()).getLevel()> RoleLevelEnum.commonUser.getLevel()){
                    throw new RuntimeException("游客无访问权限");
                }
                break;
        }
    }


    /**
     * 是否存在注解，如果存在就获取
     * @param joinPoint
     * @return
     */
    private RequireAuth getAnnotationAuth(JoinPoint joinPoint) {
        Signature signature = joinPoint.getSignature();
        MethodSignature methodSignature = (MethodSignature) signature;
        Method method = methodSignature.getMethod();
        RequireAuth requireAuth=null;
        if (method != null) {
            requireAuth= method.getAnnotation(RequireAuth.class);
        }
        if(requireAuth!=null){
            return requireAuth;
        }
        Class classT=methodSignature.getDeclaringType();
        if (classT != null) {
            requireAuth= (RequireAuth)classT.getAnnotation(RequireAuth.class);
        }
        return requireAuth;
    }

    //前后端分离登录拦截返回
    private void markLoginResponse(String msg) {
        try {
            HttpServletResponse response = HttpServletUtil.getResponse();
            response.setStatus(HttpStatus.OK.value());
            response.setContentType(MediaType.APPLICATION_JSON_VALUE);
            response.setCharacterEncoding("UTF-8");
            response.setHeader("Cache-Control", "no-cache, must-revalidate");
            JSONObject baseResopnse = new JSONObject();
            baseResopnse.put("code", SsoConstant.NO_LOGIN);
            baseResopnse.put("status", SsoConstant.RESPONSE_STATUS_LOGINOUT);
            baseResopnse.put("message", "无效token或token已过期");
            if (StrUtil.isNotEmpty(msg)) {
                baseResopnse.put("message", msg);
            }
            String jsonResult = JSON.toJSONString(baseResopnse, SerializerFeature.WriteNullStringAsEmpty);
            response.getOutputStream().write(jsonResult.getBytes());
        }catch (Exception exception){
            throw new RuntimeException(exception);
        }
    }
}
